@@ -1,14 +1,17 @@
 from tabulate import tabulate
 
-from omg.common.helper import age
+from omg.common.helper import age, extract_labels
 
 
-def bc_out(t, ns, res, output, show_type):
+def bc_out(t, ns, res, output, show_type, show_labels):
     output_res=[[]]
     # header
     if ns == '_all':
         output_res[0].append('NAMESPACE')
-    output_res[0].extend(['NAME','TYPE','FROM','LATEST'])
+    if show_labels:
+      output_res[0].extend(['NAME','TYPE','FROM','LATEST','LABELS'])
+    else:
+      output_res[0].extend(['NAME','TYPE','FROM','LATEST'])
     # resources
     for r in res:
         bc = r['res']
@@ -36,6 +39,10 @@ def bc_out(t, ns, res, output, show_type):
             row.append(bc['status']['lastVersion'])
         except:
             row.append('??')
+        # show-labels
+        if show_labels:
+            row.append(extract_labels(bc))
+
         output_res.append(row)
 
     print(tabulate(output_res,tablefmt="plain"))
