@@ -1,14 +1,17 @@
 from tabulate import tabulate
 
-from omg.common.helper import age
+from omg.common.helper import age, extract_labels
 
 
-def build_out(t, ns, res, output, show_type):
+def build_out(t, ns, res, output, show_type, show_labels):
     output_res=[[]]
     # header
     if ns == '_all':
         output_res[0].append('NAMESPACE')
-    output_res[0].extend(['NAME','TYPE','FROM','STATUS', 'STARTED','DURATION'])
+    if show_labels:
+        output_res[0].extend(['NAME','TYPE','FROM','STATUS', 'STARTED','DURATION','LABELS'])
+    else:
+        output_res[0].extend(['NAME','TYPE','FROM','STATUS', 'STARTED','DURATION'])
     # resources
     for r in res:
         build = r['res']
@@ -48,6 +51,10 @@ def build_out(t, ns, res, output, show_type):
             row.append(str(int((build['status']['duration']) / 1000000000)) + 's')
         except:
             row.append('Unknown')
+        # show-labels
+        if show_labels:
+            row.append(extract_labels(build))
+
         output_res.append(row)
 
     print(tabulate(output_res,tablefmt="plain"))
