@@ -1,11 +1,14 @@
 from tabulate import tabulate
 
-from omg.common.helper import age
+from omg.common.helper import age, extract_labels
 
-def sc_out(t, ns, res, output, show_type):
+def sc_out(t, ns, res, output, show_type, show_labels):
     output_res=[]
     # header
-    header = ['NAME','PROVISIONER','RECLAIMPOLICY','VOLUMEBINDINGMODE','ALLOWVOLUMEEXPANSION','AGE']
+    if show_labels:
+        header = ['NAME','PROVISIONER','RECLAIMPOLICY','VOLUMEBINDINGMODE','ALLOWVOLUMEEXPANSION','AGE','LABELS']
+    else:
+        header = ['NAME','PROVISIONER','RECLAIMPOLICY','VOLUMEBINDINGMODE','ALLOWVOLUMEEXPANSION','AGE']
     # resources
     for r in res:
         sc = r['res']
@@ -33,6 +36,9 @@ def sc_out(t, ns, res, output, show_type):
             row.append(age(ct,ts))
         except:
             row.append('Unknown')
+        # show-labels
+        if show_labels:
+            row.append(extract_labels(sc))
 
         output_res.append(row)
 
