@@ -10,7 +10,7 @@ _omg_completion() {
 }
 
 _omg_completionetup() {
-    local COMPLETION_OPTIONS=""
+    local COMPLETION_OPTIONS="-o default"
     local BASH_VERSION_ARR=(${BASH_VERSION//./ })
     # Only BASH version 4.4 and later have the nosort option.
     if [ ${BASH_VERSION_ARR[0]} -gt 4 ] || ([ ${BASH_VERSION_ARR[0]} -eq 4 ] && [ ${BASH_VERSION_ARR[1]} -ge 4 ]); then
@@ -21,4 +21,4 @@ _omg_completionetup() {
 }
 
 _omg_completionetup;
-"""
\ No newline at end of file
+"""
